BoxData class

Annotations

Constructors

BoxData({required String name, Map<Object, InspectorFrame>? frames, bool open = true, bool loaded = false})

Properties

frames Map<Object, InspectorFrame>
final
hashCode int
The hash code for this object.
no setterinherited
loaded bool
final
name String
final
open bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? open}) BoxData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited