BoxEventPayload class
Payload for a box event
- Annotations
-
- @JsonSerializable.new()
- @immutable
Constructors
- BoxEventPayload({required String box, required InspectorFrame frame})
-
Constructor
const
-
BoxEventPayload.fromJson(Map<
String, dynamic> json) -
From json
factory
Properties
- box → String
-
The box name
final
- frame → InspectorFrame
-
The event frame
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InspectorFrame? frame}) → BoxEventPayload - Copy with
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - To json
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited