InspectorFrame class

An inspector frame

Annotations

Constructors

InspectorFrame({required Object key, required Object? value, bool lazy = false, bool deleted = false})
Constructor
const
InspectorFrame.fromFrame(Frame frame)
From frame
factory
InspectorFrame.fromJson(Map<String, dynamic> json)
From json
factory

Properties

deleted bool
Whether the frame is deleted
final
hashCode int
The hash code for this object.
no setterinherited
key Object
The frame key
final
lazy bool
Whether the frame is lazy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
The frame value
final

Methods

copyWith({required Object? value, bool? lazy}) InspectorFrame
Copy with
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
To json
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited