RawEnum class

A raw enum value read from the buffer

Inheritance

Constructors

RawEnum(String name, String value)
Constructor
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The type name
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The enum value
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited