RawField class

A raw field of a custom object

Annotations

Constructors

RawField(String name, Object? value)
Constructor
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the field
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
The value of the field
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited