RawObject class

A raw custom object read from the buffer

Inheritance

Constructors

RawObject(String name, List<RawField> fields)
Constructor
const

Properties

fields List<RawField>
The fields of the object
final
hashCode int
The hash code for this object.
no setterinherited
name String
The type name
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited