RawObjectReader class

A binary reader that reads raw objects

Constructors

RawObjectReader(Map<String, RiftSchemaType> _types, Uint8List buffer)
Constructor

Properties

availableBytes int
The number of bytes left in this entry.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usedBytes int
The number of read bytes.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peekBytes(int bytes) Uint8List
Get a Uint8List view which contains the next bytes bytes. This does not advance the internal read position.
inherited
peekUint32() int
Not part of public API
inherited
read([int? typeId]) → dynamic
Read and decode any value.
readBool() bool
Read a boolean.
inherited
readBoolList([int? length]) List<bool>
Read a list of booleans with length.
inherited
readByte() int
Read a single byte.
inherited
readByteList([int? length]) Uint8List
Read a list of bytes with length.
inherited
readBytes(int length) Uint8List
Read length bytes from the buffer
inherited
readDouble() double
Read eight bytes as 64-bit double.
inherited
readDoubleList([int? length]) List<double>
Read a list of doubles with length.
inherited
readEncrypted(RiftCipher cipher) → dynamic
Not part of public API
inherited
readFrame({RiftCipher? cipher, int? keyCrc, bool lazy = false, int frameOffset = 0, bool verbatim = false}) → Frame?
Not part of public API
inherited
readInt() int
Read eight bytes as 64-bit signed integer.
inherited
readInt32() int
Read four bytes as 32-bit signed integer.
inherited
readIntList([int? length]) List<int>
Read a list of integers with length.
inherited
readKey() → dynamic
Not part of public API
inherited
readList([int? length]) List
Read a list with length.
inherited
readMap([int? length]) Map
Read a map with length entries.
inherited
readRiftList([int? length]) → RiftList<RiftObjectMixin>
Read a RiftList with length.
inherited
readString([int? byteCount, Converter<List<int>, String> decoder = BinaryReader.utf8Decoder]) String
Read byteCount bytes and decode an UTF-8 String.
inherited
readStringList([int? length, Converter<List<int>, String> decoder = BinaryReader.utf8Decoder]) List<String>
Read a list of Strings with length.
inherited
readTypeId() int
Read a type ID and handle extension
inherited
readUint32() int
Read four bytes as 32-bit unsigned integer.
inherited
readWord() int
Read two bytes as 16-bit unsigned integer.
inherited
skip(int bytes) → void
Skip n bytes.
inherited
toString() String
A string representation of this object.
inherited
viewBytes(int bytes) Uint8List
Get a Uint8List view which contains the next bytes bytes.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited