RiftSchema class

Information about Rift adapters used to support incremental changes

Annotations

Constructors

RiftSchema({required int nextTypeId, required Map<String, RiftSchemaType> types})
Constructor
const
RiftSchema.fromJson(Map<String, dynamic> json)
From json
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
nextTypeId int
The next type ID to use for future updates
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types Map<String, RiftSchemaType>
The adapter types
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
To json
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

comment → const String
The comment placed at the top of the schema file