ConnectClient class

Annotations

Constructors

ConnectClient(VmService vmService, String isolateId, Map<String, RiftSchemaType> types)

Properties

boxEvent Stream<BoxEventPayload>
no setter
boxRegistered Stream<String>
no setter
boxUnregistered Stream<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
isolateId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types Map<String, RiftSchemaType>
final
vmService → VmService
final

Methods

getBoxFrames(String name) Future<List<InspectorFrame>>
listBoxes() Future<List<String>>
loadValue(String name, InspectorFrame frame) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

connect() Future<ConnectClient>